@@ -1,15 +1,21 @@
 /* Built-in files */
 
 /*
-	<jupprc grep -v $'^[\t ]' | while IFS= read -r x; do
+	LC_ALL=C grep -ve $'^[\t ]' -e '^-syntax' jupprc | sed \
+	    -e '/^:cua/,$d' -e '/^:Pastecua/,/^$/d' -e 1d \
+	    -e 's/@(#) jupprc/@(#) blt_in/' | cat -s | while IFS= read -r x; do
 		x=${x//\\/\\\\}; print -r -- $'\t\t'\""${x//\"/\\\"}\n"\";
-	done | perl -pi -e 's/[^\ca-~]/sprintf "\\x%02X", unpack("U", $&)/eg'
+	done | perl -pe 's/[^\ca-~]/sprintf "\\x%02X", unpack("U", $&)/eg'
  */
 
 #include "types.h"
 
+#ifndef JUPPRC_BUILTIN_NAME
+#define JUPPRC_BUILTIN_NAME "jupprc"
+#endif
+
 const unsigned char * const builtins[] = {
-	US "jupprc", US
+	US JUPPRC_BUILTIN_NAME, US
 		"-asis\n"
 		"-assume_color\n"
 		"-dopadding\n"
@@ -72,7 +78,7 @@ const unsigned char * const builtins[] = {
 		"\\i \\i^A previous word ^QS beg. of line ^KY kill ^T  >word ^QL refresh  ^KZ shell  \\i \\i\n"
 		"\\i \\i^F next word     ^QD end of line  ^K/ pipe ^QY >line ^O  options  \\u\\bFILE\\b\\u       \\i \\i\n"
 		"\\i \\i\\u\\bSEARCH\\b\\u           ^QR top of file  ^KB begin          \\u\\bBUFFER\\b\\u       ^KE new    \\i \\i\n"
-		"\\i \\i^QF find first   ^QC end of file  ^KK end  ^K] space ^U undo      ^KR import \\i \\i\n"
+		"\\i \\i^QF find first   ^QC end of file  ^KK end            ^U undo      ^KR import \\i \\i\n"
 		"\\i \\i^L  find next    ^QO byte offset  ^KD reformat       ^^ redo      ^KW export \\i \\i\n"
 		"}\n"
 		"\n"
@@ -102,13 +108,14 @@ const unsigned char * const builtins[] = {
 		"\n"
 		"{Programs\n"
 		"\\i   Help Screen    turn off with ^J     prev. screen ^[,    next screen ^[.     \\i\n"
-		"\\i \\i\\u\\bGOTO\\b\\u                  \\u\\bCOMPILING\\b\\u                    \\u\\bINDENT\\b\\u       \\u\\bSLIDING\\b\\u      \\i \\i\n"
-		"\\i \\i^Q- to column number  ^[C Compile & parse errors   ^K. more     ^W up        \\i \\i\n"
-		"\\i \\i^QI to line number    ^[E Parse errors             ^K, less     ^Z down      \\i \\i\n"
-		"\\i \\i^QP previous place    \\u\\bGOTO AFTER COMPILING\\b\\u         ^KA center   \\u\\bINSERT MATH\\b\\u  \\i \\i\n"
-		"\\i \\i^K= next place        ^[N previous error    \\u\\bSPECIAL\\b\\u             ^[# equation \\i \\i\n"
-		"\\i \\i^Q[ matching brace    ^[M next error        ^[- exec. juppcmd   ^[= result   \\i \\i\n"
-		"\\i \\i \\b\\uFreedroidz\\u:\\b ^KF save current *.nxc file, compile, transfer to the NXT brick \\i \\i\n"
+		"\\i \\i\\u\\bGOTO\\b\\u                               \\u\\bCOMPILING\\b\\u                    \\u\\bSLIDING\\b\\u      \\i \\i\n"
+		"\\i \\i^Q] matching brace, ^Q[ reverse    ^[C compile & parse errors   ^W up        \\i \\i\n"
+		"\\i \\i^Q= merge conflict marker          ^[E parse errors             ^Z down      \\i \\i\n"
+		"\\i \\i^Q- to column number  \\u\\bINDENT\\b\\u       ^KF save, compile & upload to NXT brick   \\i \\i\n"
+		"\\i \\i^QI to line number    ^K. more     \\u\\bGOTO AFTER COMPILING\\b\\u         \\u\\bINSERT MATH\\b\\u  \\i \\i\n"
+		"\\i \\i^QP previous place    ^K, less     ^[N previous error           ^[# equation \\i \\i\n"
+		"\\i \\i^K= next place        ^KA centre   ^[M next error      \\u\\bSPECIAL\\b\\u  ^[= result   \\i \\i\n"
+		"\\i \\i                      ^K] kill whitespace at EOL       ^[- jupp command line \\i \\i\n"
 		"}\n"
 		"\n"
 		"{Search\n"
@@ -142,7 +149,7 @@ const unsigned char * const builtins[] = {
 		"\\i \\i go to \\uhttp://sf.net/projects/joe-editor/\\u for upstream bug reports. JUPP 2.8 \\i \\i\n"
 		"\\i \\i for DOS compiled by A. Totlis, packed with LHarc 2.13; JUPP 3.x for UNIX\\d(R)\\d \\i \\i\n"
 		"\\i \\i at \\uhttp://mirbsd.de/jupp\\u and by \\bThorsten \"\\dmirabilos\\d\" Glaser <\\utg@mirbsd.org\\u>\\b \\i \\i\n"
-		"\\i \\i @(#) blt_in 2014-10-23; 3.1; autoCR-LF; UTF-8 via locale; per-file encoding \\i \\i\n"
+		"\\i \\i @(#) blt_in 2016-10-08; 3.1; autoCR-LF; UTF-8 via locale; per-file encoding \\i \\i\n"
 		"}\n"
 		"\n"
 		"{CharTable\n"
@@ -227,6 +234,7 @@ const unsigned char * const builtins[] = {
 		":main\n"
 		":inherit windows\n"
 		"bof,qrepl,\"\\\\[\",quote,\"i\",quote,\"k\",quote,\"l\",quote,\"m ]\\\\+\\\\[\",quote,\"i\",quote,\"k\",quote,\"l\",quote,\"m ]\\\\$\",rtn,rtn,rtn,\"r\",eof	^K ]\n"
+		"ffirst,\"\\\\^\\\\[<>=]\\\\[<>=]\\\\[<>=]\\\\[<>=]\\\\[<>=]\\\\[<>=]\\\\[<>=]\\\\[ \\\\n]\",rtn,rtn,ltarw							^Q =\n"
 		"splitw,prevw,scratch,\"nbc-Output\",rtn,nextw,save,markk,bol,markb,prevw,prevw,blkcpy,nextw,nextw,rtn,prevw,eol,\"'\",bol,qrepl,\"'\",rtn,rtn,\"'\\\\\\\\''\",rtn,\"r\",backs,backs,backs,bol,\"fn='\",eol,rtn,\"case $fn in\",rtn,\"*.nxc) ;;\",rtn,\"*) echo '==> Error: filename not *.nxc'; exit ;;\",rtn,\"esac\",rtn,\"nbc -d \\\"$fn\\\"; x=$?\",rtn,\"if test $x = 0; then echo '==> OK'; else echo '==> Error code:' $x; fi\",rtn,nmark,filt,\"sh\",rtn,rtn,\"Press ^KQ to close this window!\",rtn	^K F\n"
 		"splitw,prevw,scratch,\"nbc-Output\",rtn,nextw,save,markk,bol,markb,prevw,prevw,blkcpy,nextw,nextw,rtn,prevw,eol,\"'\",bol,qrepl,\"'\",rtn,rtn,\"'\\\\\\\\''\",rtn,\"r\",backs,backs,backs,bol,\"fn='\",eol,rtn,\"case $fn in\",rtn,\"*.nxc) ;;\",rtn,\"*) echo '==> Error: filename not *.nxc'; exit ;;\",rtn,\"esac\",rtn,\"nbc -d \\\"$fn\\\"; x=$?\",rtn,\"if test $x = 0; then echo '==> OK'; else echo '==> Error code:' $x; fi\",rtn,nmark,filt,\"sh\",rtn,rtn,\"Press ^KQ to close this window!\",rtn	^K f\n"
 		"splitw,prevw,scratch,\"nbc-Output\",rtn,nextw,save,markk,bol,markb,prevw,prevw,blkcpy,nextw,nextw,rtn,prevw,eol,\"'\",bol,qrepl,\"'\",rtn,rtn,\"'\\\\\\\\''\",rtn,\"r\",backs,backs,backs,bol,\"fn='\",eol,rtn,\"case $fn in\",rtn,\"*.nxc) ;;\",rtn,\"*) echo '==> Error: filename not *.nxc'; exit ;;\",rtn,\"esac\",rtn,\"nbc -d \\\"$fn\\\"; x=$?\",rtn,\"if test $x = 0; then echo '==> OK'; else echo '==> Error code:' $x; fi\",rtn,nmark,filt,\"sh\",rtn,rtn,\"Press ^KQ to close this window!\",rtn	^K ^F\n"
@@ -443,11 +451,11 @@ const unsigned char * const builtins[] = {
 		"tomarkk		^Q ^K\n"
 		"tomarkk		^Q k\n"
 		"tomarkk		^[ q k\n"
-		"tomatch		^Q [\n"
+		"rvmatch		^Q [\n"
 		"tomatch		^Q ]\n"
-		"tomatch		^Q ^[\n"
+		"rvmatch		^Q ^[\n"
 		"tomatch		^Q ^]\n"
-		"tomatch		^[ q [\n"
+		"rvmatch		^[ q [\n"
 		"tomatch		^[ q ]\n"
 		"tos		^Q E\n"
 		"tos		^Q ^E\n"
@@ -534,5 +542,5 @@ const unsigned char * const builtins[] = {
 		":querysr\n"
 		"type		^@ TO \xFF\n"
 ,	NULL
-,	"@(#) $MirOS: contrib/code/jupp/builtins.c,v 1.20 2014/10/23 16:34:18 tg Exp $"
+,	"@(#) $MirOS: contrib/code/jupp/builtins.c,v 1.23 2016/10/29 21:42:56 tg Exp $"
 };
