@@ -1,6 +1,6 @@
-/* $MirOS: contrib/code/jupp/main.c,v 1.23 2014/03/04 23:04:11 tg Exp $ */
+/* $MirOS: contrib/code/jupp/main.c,v 1.26 2016/10/29 23:44:45 tg Exp $ */
 
-#define JUPP_IS_COPYRIGHT_C_BY "2014 mirabilos"
+#define JUPP_IS_COPYRIGHT_C_BY "2016 mirabilos"
 
 /*-
  * Copyright (c) 2004ff. Thorsten Glaser
@@ -16,7 +16,7 @@
  * example libraries or when using crunchgen, into a combined binary,
  * that may be conveyed under any version of the GPL, as published by
  * the Free Software Foundation, and any compatible licence permitted
- * by the GPL.
+ * by any version of the GPL, as above.
  *
  * This work is provided "AS IS" and WITHOUT WARRANTY of any kind, to
  * the utmost extent permitted by applicable law, neither express nor
@@ -192,6 +192,7 @@ int main(int argc, char **argv, char **envp)
 	int backopt;
 	int c;
 
+	init_JOERC();
 	joe_locale();
 
 	mainenv = (unsigned char **)envp;
@@ -235,21 +236,23 @@ int main(int argc, char **argv, char **envp)
 		}
 	}
 
-	vsrm(s);
-	s = vsncpy(NULL, 0, sc(JOERC));
-	s = vsncpy(sv(s), sv(run));
-	s = vsncpy(sv(s), sc("rc"));
-	c = procrc(cap, s);
-	if (c == 0)
-		goto donerc;
-	if (c == 1) {
-		unsigned char buf[8];
-
-		fprintf(stderr, "There were errors in '%s'.  Use it anyway?", s);
-		fflush(stderr);
-		if (fgets((char *)buf, 8, stdin) != NULL &&
-		    (buf[0] == 'y' || buf[0] == 'Y'))
+	if (has_JOERC) {
+		vsrm(s);
+		s = vsncpy(NULL, 0, sz(get_JOERC));
+		s = vsncpy(sv(s), sv(run));
+		s = vsncpy(sv(s), sc("rc"));
+		c = procrc(cap, s);
+		if (c == 0)
 			goto donerc;
+		if (c == 1) {
+			unsigned char buf[8];
+
+			fprintf(stderr, "There were errors in '%s'.  Use it anyway?", s);
+			fflush(stderr);
+			if (fgets((char *)buf, 8, stdin) != NULL &&
+			    (buf[0] == 'y' || buf[0] == 'Y'))
+				goto donerc;
+		}
 	}
 
 	/* Try built-in joerc */
