@@ -1,4 +1,4 @@
-/* $MirOS: contrib/code/jupp/rc.c,v 1.19 2012/12/30 21:45:16 tg Exp $ */
+/* $MirOS: contrib/code/jupp/rc.c,v 1.21 2016/10/29 23:44:45 tg Exp $ */
 /*
  *	*rc file parser
  *	Copyright
@@ -609,7 +609,7 @@ static int syntaxcmplt(BW *bw)
 		unsigned char *p;
 		int x, y;
 
-		if (chpwd(US (JOERC "syntax")))
+		if (chJpwd(US ("syntax")))
 			return -1;
 		t = rexpnd(US "*.jsf");
 		if (!t) {
@@ -984,7 +984,7 @@ int procrc(CAP *cap, unsigned char *name)
 					/* do nothing */;
 				if (buf[0] != '}') {
 					err = 1;
-					fprintf(stderr, "\n%s:%d: End of joerc file occured before end of help text\n", name, line);
+					fprintf(stderr, "\n%s:%d: End of joerc file occurred before end of help text\n", name, line);
 					break;
 				}
 			}
